#!/usr/bin/env bash
cat > $1/src/Makefile.am <<EOF
bin_PROGRAMS = $1
${1}_SOURCES = main.cpp
EOF
